@@ -26,6 +26,13 @@ type ChatOptions struct {
 	Seed               int
 	ModelContextLength int
 	MaxTokens          int
+	Search             bool
+	SearchLocation     string
+	ImageFile          string
+	ImageSize          string
+	ImageQuality       string
+	ImageCompression   int
+	ImageBackground    string
 }
 
 // NormalizeMessages remove empty messages and ensure messages order user-assist-user
